@@ -1,13 +1,4 @@
 (**************************************************************)
-(*
- *  Ensemble, 1.10
- *  Copyright 2001 Cornell University, Hebrew University
- *  All rights reserved.
- *
- *  See ensemble/doc/license.txt for further information.
- *)
-(**************************************************************)
-(**************************************************************)
 (* LOCAL.ML *)
 (* Author: Mark Hayden, 6/95 *)
 (**************************************************************)
@@ -49,6 +40,6 @@ in {up_in=up_hdlr;uplm_in=uplm_hdlr;upnm_in=upnm_hdlr;dn_in=dn_hdlr;dnnm_in=dnnm
 
 let l args vf = Layer.hdr init hdlrs None (FullNoHdr ()) args vf
 
-let _ = Elink.layer_install name l
+let _ = Layer.install name l
 
 (**************************************************************)
