@@ -33,7 +33,7 @@ type state = {
 (**************************************************************)
 
 let init _ (ls,vs) = {
-  alarm	  = Elink.alarm_get_hack () ;
+  alarm	  = Alarm.get_hack () ;
   failed  = ls.falses ;
   all_alive = true ;
   enabled = true
@@ -205,6 +205,6 @@ in {up_in=up_hdlr;uplm_in=uplm_hdlr;upnm_in=upnm_hdlr;dn_in=dn_hdlr;dnnm_in=dnnm
 let l args vs = Layer.hdr init hdlrs None (FullNoHdr NoHdr) args vs
 let l2 args vs = Layer.hdr_noopt init hdlrs args vs
 
-let _ = Elink.layer_install name l
+let _ = Layer.install name l
 
 (**************************************************************)
